@@ -76,7 +76,10 @@ class SyncManager:
             path: Path to the file that will be written
             content: The exact bytes that will be written to the file
         """
-        path_str = str(Path(path).resolve())
+        from griptape_nodes.retained_mode.griptape_nodes import GriptapeNodes
+
+        os_manager = GriptapeNodes.OSManager()
+        path_str = str(os_manager.resolve_path_safely(Path(path)))
         file_hash = hashlib.sha256(content).hexdigest()
         with self._hash_lock:
             self._file_hashes[path_str] = file_hash
@@ -164,8 +167,15 @@ class SyncManager:
         try:
             # Check if cloud storage is configured before attempting sync
             self._get_cloud_storage_driver()
-            # Start file watching after successful sync
-            self._start_file_watching()
+
+            # Check if file watching is enabled before starting it
+            enable_file_watching = self._config_manager.get_config_value("enable_workspace_file_watching", default=True)
+            if enable_file_watching:
+                # Start file watching after successful sync
+                self._start_file_watching()
+                logger.debug("File watching enabled - started watching synced workflows directory")
+            else:
+                logger.debug("File watching disabled - skipping file watching startup")
 
             logger.info("App initialization complete - starting automatic cloud workflow sync")
 
@@ -449,7 +459,7 @@ class SyncManager:
 
             # Collect results as they complete
             for future in future_to_filename:
-                filename, success, error = future.result()
+                filename, success, _error = future.result()
                 if success:
                     synced_workflows.append(filename)
                 else:
